from flask import Blueprint, render_template, request, abort, Response, redirect, url_for
from rascunho.database import db
from rascunho.types.document import Document
from hashlib import sha1

basic = Blueprint('basic', __name__)

@basic.route("/", methods = ['GET', 'POST'])
def index():
    if request.method == "GET":
        doc = Document.query.order_by(Document.created_at.asc()).first()
        return render_template('index.html', doc = doc)
    else:
        return create(request.form)

@basic.route("/<sha>", methods = ['GET'])
def show(sha):
    doc = Document.query.filter(Document.sha == sha).one_or_none()

    if not doc:
        abort(404)

    return render_template('preview.html', doc = doc)

@basic.route("/<sha>/raw", methods = ['GET'])
def raw(sha):
    doc = Document.query.filter(Document.sha == sha).one_or_none()

    if not doc:
        abort(404)

    return Response(doc.content, mimetype="text/plain")

def create(params):
    doc = None
    content = params['text']

    if not content:
        abort(422)

    sha = sha1()
    sha.update(content.encode())
    sha.update(request.remote_addr.encode())

    existing_doc = Document.query.filter(Document.sha == sha.hexdigest()).one_or_none()

    if existing_doc:
        doc = existing_doc
    else:
        doc = Document()

    doc.sha = sha.hexdigest()
    doc.content = content

    db.add(doc)
    db.commit()
    db.flush()

    return redirect(url_for('basic.show', sha = doc.sha))
